from sqlalchemy.orm import Session
from typing import Optional, List
from models.user import User
from tools.db_helper.sqlserver_helper import SQLServerHelper

class UserStore:
    def __init__(self, session: Session = None):
        if session is None:
            session_maker = SQLServerHelper().get_session_maker("db.sqlserver_mian")
            self.session = session_maker()
        else:
            self.session = session

    def get_user_by_id(self, user_id: int) -> Optional[User]:
        """根据用户ID获取用户信息"""
        return self.session.query(User).filter(User.id == user_id).first()

    def get_user_by_username(self, username: str) -> Optional[User]:
        """根据用户名获取用户信息"""
        return self.session.query(User).filter(User.username == username).first()

    def get_all_users(self) -> List[User]:
        """获取所有用户列表"""
        return self.session.query(User).all()



    def authenticate_user(self, username: str, password: str) -> Optional[User]:
        """用户认证"""
        user = self.get_user_by_username(username)
        if user and user.password == password:
            return user
        return None